@@ -1,7 +1,11 @@
 """Voice interface subpackage."""
 
 from .keyword import KeywordDetector
-from .microphone_stream import MicrophoneStream
+from .microphone_stream import (
+    MicrophoneStream,
+    pause_microphone_stream,
+    resume_microphone_stream,
+)
 from .speech_to_text import RecognitionString, SpeechToText
 from .text_to_speech import TextToSpeech
 
@@ -14,9 +18,9 @@ class SpeechInterface:
         self.sst = SpeechToText(rate)
         self.tts = TextToSpeech()
 
-    def output(self, text: str) -> None:
+    def output(self, text: str, cache: bool = False) -> None:
         """Pronounce text."""
-        self.tts.say(text)
+        self.tts.say(text, cache)
 
     def input(self) -> str:
         """Recognize speech."""
@@ -30,4 +34,6 @@ __all__ = [
     "TextToSpeech",
     "SpeechInterface",
     "MicrophoneStream",
+    "pause_microphone_stream",
+    "resume_microphone_stream",
 ]
