@@ -22,7 +22,10 @@ def pre_setup() -> None:
                 raise
 
     sample_config = {
-        "triggerword": {"picovoice": {"word": "jarvis", "sensitivity": 0.5}},
+        "triggerword": {
+            "picovoice": {"word": "jarvis", "sensitivity": 0.5},
+            "sound": "now",
+        },
         "prerecord_seconds": 3,
         "tts": {
             "aws": {
